From e44876fe7fec3bd1ad67f3c351ead6d42c91ac3f Mon Sep 17 00:00:00 2001
From: Daniel Gustafsson <daniel@yesql.se>
Date: Wed, 16 Aug 2017 22:18:19 +0200
Subject: [PATCH] Remove mentions of serverside CRL and CA files

Commit a445cb92ef5b3a31313ebce30e18cc1d6e0bdecb removed the default
filenames for serverside CRL and CA files, but left them in the docs
with a small note. This removes the note, and the previous default
names, to clarify as well as changes mentions of the filenames to
make it clearer that they are configurable.
---
 doc/src/sgml/config.sgml  | 10 ++++++----
 doc/src/sgml/libpq.sgml   |  4 ++--
 doc/src/sgml/runtime.sgml | 10 +++++-----
 doc/src/sgml/sslinfo.sgml |  2 +-
 4 files changed, 14 insertions(+), 12 deletions(-)

diff --git a/doc/src/sgml/config.sgml b/doc/src/sgml/config.sgml
index 2b6255ed95..4aea9a2731 100644
--- a/doc/src/sgml/config.sgml
+++ b/doc/src/sgml/config.sgml
@@ -984,8 +984,9 @@ include_dir 'conf.d'
         and client certificate verification is not performed.
        </para>
        <para>
-        In previous releases of PostgreSQL, the name of this file was
-        hard-coded as <filename>root.crt</filename>.
+        In earlier versions of PostgreSQL, the name of this file was
+        hard-coded as <filename>root.crt</filename>. As of
+        <productname>PostgreSQL</> 9.2 it is a configuration parameter.
        </para>
       </listitem>
      </varlistentry>
@@ -1023,8 +1024,9 @@ include_dir 'conf.d'
         The default is empty, meaning no CRL file is loaded.
        </para>
        <para>
-        In previous releases of PostgreSQL, the name of this file was
-        hard-coded as <filename>root.crl</filename>.
+        In earlier versions of PostgreSQL, the name of this file was
+        hard-coded as <filename>root.crl</filename>. As of
+        <productname>PostgreSQL</> 9.2 it is a configuration parameter.
        </para>
       </listitem>
      </varlistentry>
diff --git a/doc/src/sgml/libpq.sgml b/doc/src/sgml/libpq.sgml
index ad5e9b95b4..b00552b883 100644
--- a/doc/src/sgml/libpq.sgml
+++ b/doc/src/sgml/libpq.sgml
@@ -7637,8 +7637,8 @@ ldap://ldap.acme.com/cn=dbserver,cn=hosts?pgconnectinfo?base?(objectclass=*)
    certificate of the signing authority to the <filename>postgresql.crt</>
    file, then its parent authority's certificate, and so on up to a certificate
    authority, <quote>root</> or <quote>intermediate</>, that is trusted by
-   the server, i.e. signed by a certificate in the server's
-   <filename>root.crt</filename> file.
+   the server, i.e. signed by a certificate in the server's root certificate
+   file.
   </para>
 
   <para>
diff --git a/doc/src/sgml/runtime.sgml b/doc/src/sgml/runtime.sgml
index 6d57525515..83115c9191 100644
--- a/doc/src/sgml/runtime.sgml
+++ b/doc/src/sgml/runtime.sgml
@@ -2264,7 +2264,7 @@ pg_dumpall -p 5432 | psql -d postgres -p 5433
   <para>
    To require the client to supply a trusted certificate, place
    certificates of the certificate authorities (<acronym>CA</acronym>s)
-   you trust in the file <filename>root.crt</filename> in the data
+   you trust in a file named <filename>root.crt</filename> in the data
    directory, set the parameter <xref linkend="guc-ssl-ca-file"> in
    <filename>postgresql.conf</filename> to <literal>root.crt</literal>,
    and add the authentication option <literal>clientcert=1</literal> to the
@@ -2320,8 +2320,8 @@ pg_dumpall -p 5432 | psql -d postgres -p 5433
 
    <para>
     <xref linkend="ssl-file-usage"> summarizes the files that are
-    relevant to the SSL setup on the server.  (The shown file names are default
-    or typical names.  The locally configured names could be different.)
+    relevant to the SSL setup on the server.  (The shown file names are default,
+    the locally configured names could be different.)
    </para>
 
   <table id="ssl-file-usage">
@@ -2351,14 +2351,14 @@ pg_dumpall -p 5432 | psql -d postgres -p 5433
      </row>
 
      <row>
-      <entry><xref linkend="guc-ssl-ca-file"> (<filename>$PGDATA/root.crt</>)</entry>
+      <entry><xref linkend="guc-ssl-ca-file"></entry>
       <entry>trusted certificate authorities</entry>
       <entry>checks that client certificate is
       signed by a trusted certificate authority</entry>
      </row>
 
      <row>
-      <entry><xref linkend="guc-ssl-crl-file"> (<filename>$PGDATA/root.crl</>)</entry>
+      <entry><xref linkend="guc-ssl-crl-file"></entry>
       <entry>certificates revoked by certificate authorities</entry>
       <entry>client certificate must not be on this list</entry>
      </row>
diff --git a/doc/src/sgml/sslinfo.sgml b/doc/src/sgml/sslinfo.sgml
index 7bda33efa3..c720601cf5 100644
--- a/doc/src/sgml/sslinfo.sgml
+++ b/doc/src/sgml/sslinfo.sgml
@@ -150,7 +150,7 @@
     </para>
     <para>
      This function is really useful only if you have more than one trusted CA
-     certificate in your server's <filename>root.crt</> file, or if this CA
+     certificate in your server's root certificate file, or if this CA
      has issued some intermediate certificate authority certificates.
     </para>
     </listitem>
-- 
2.14.1.145.gb3622a4ee

